rustc_config

Function rustc_config 

pub fn rustc_config(from_crate: &str, io: Option<(Names, Names)>) -> Result<()>
Creates rustc compilation flags

The compilations flags are created according to the availability of some inputs and outputs. If no inputs and outputs are given, then io_names is used to retrieve all of them.

The compilation flags that rustc_config creates are:

  • mount
  • m1
  • m1_hp_force_extension
  • m2
  • top-end="ASM"
  • top-end="FSM"
  • m2_rbm="MCM2Lcl6D"
  • m2_rbm="MCM2Lcl"
  • cfd2021
  • cfd2025
  • ground_acceleration